@@ -16,7 +16,7 @@
 import github.GithubObject
 
 
-class GitBlob(github.GithubObject.GithubObject):
+class GitBlob(github.GithubObject.CompletableGithubObject):
     """
     This class represents GitBlobs as returned for example by http://developer.github.com/v3/todo
     """
