@@ -18,7 +18,7 @@ import github.GithubObject
 import github.NamedUser
 
 
-class IssueComment(github.GithubObject.GithubObject):
+class IssueComment(github.GithubObject.CompletableGithubObject):
     """
     This class represents IssueComments as returned for example by http://developer.github.com/v3/todo
     """
